summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/order_backup.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/order_backup.cpp b/src/order_backup.cpp
index 5e634d695..4e21130c2 100644
--- a/src/order_backup.cpp
+++ b/src/order_backup.cpp
@@ -189,8 +189,8 @@ CommandCost CmdClearOrderBackup(DoCommandFlag flags, TileIndex tile, ClientID us
uint32 user = _networking && !_network_server ? _network_own_client_id : CLIENT_ID_SERVER;
for (OrderBackup *ob : OrderBackup::Iterate()) {
- /* If it's not a backup of us, ignore it. */
- if (ob->user != user) continue;
+ /* If this is a GUI action, and it's not a backup of us, ignore it. */
+ if (from_gui && ob->user != user) continue;
/* If it's not for our chosen tile either, ignore it. */
if (t != INVALID_TILE && t != ob->tile) continue;